#!/usr/bin/ksh
###########################################################################
# This is the script to wrap up the installation and invocation of
# WCSICChecker for AIX. 
# 
# Author: Andrew Chen
# Created: Feb. 13 2001
# Last Modified: July 10 2002
############################################################################
#**********************************************************************
#*-------------------------------------------------------------------------------
#* Licensed Materials - Property of IBM
#*
#* 5724-A18
#*
#* (c) Copyright IBM Corp. 2000, 2001
#*
#* US Government Users Restricted Rights - Use, duplication or
#* disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#*-------------------------------------------------------------------------------

############################################################################
# define defaults 
WCSINSTALLED=0
WCS51=0
WC54=0
WAS35=0
WAS40=0
# define constants
STACK1K=32768

# control A charactor used as a separator for sed
ca=`/usr/bin/echo '\001'` 

############################################################################
#  Tokernize the version, release, modification, and fixpak
#
Tokenize()
{
CURVER=$1

CURSOFT=$2

CUREDITION=$3

CURPATH=$4

XMLFILE1=$5

XMLFILE2=$6

CURVER1=`( echo $CURVER | awk -v FS="." '{print $1}')`
if [[ "$CURVER1" = "" ]]
then
   CURVER1="0"
fi

CURVER2=`( echo $CURVER | awk -v FS="." '{print $2}')`
if [[ "$CURVER2" = "" ]]
then
   CURVER2="0"
fi

CURVER3=`( echo $CURVER | awk -v FS="." '{print $3}')`
if [[ "$CURVER3" = "" ]]
then
   CURVER3="0"
fi

CURVER4=`( echo $CURVER | awk -v FS="." '{print $4}')`
if [[ "$CURVER4" = "" ]]
then
   CURVER4="0"
fi

if [[ $CURSOFT = "AIX" ]];
then
sed s${ca}'<'$CURSOFT' edition="x" version="x" release="x" modification="x" fixpak="x" path="x">'${ca}\
'<'$CURSOFT' edition="'$CUREDITION'" version="'$CURVER1'" release="'$CURVER2'" modification="'$CURVER3\
'" fixpak="'$CURVER4'" path="'$CURPATH'">'${ca} $XMLFILE1 > $XMLFILE2
else
sed s${ca}'<'$CURSOFT' edition="x" version="x" release="x" modification="x" fixpak="x" path="x"/>'${ca}\
'<'$CURSOFT' edition="'$CUREDITION'" version="'$CURVER1'" release="'$CURVER2'" modification="'$CURVER3\
'" fixpak="'$CURVER4'" path="'$CURPATH'"/>'${ca} $XMLFILE1 > $XMLFILE2
fi

}
# check the installed package infomation and version levels
HardCheck()
{
FILESET=$1

TEMP=`(lslpp -Lq | grep $FILESET)`

if [ $? -ne 0 ]
then
   return 3
else
   CURVERS=`( lslpp -Lq  | grep $FILESET | /usr/bin/awk '{print $2}')`   
   return 0 
fi
}

#
# 0 =
# 1 >
# 2 <
# 3 NONE
#
TokenCompare()
{
COUNT=1
CURVER=$1
CURVER1=`( echo $CURVER | awk -v FS="." '{print $1}')`
CURVER2=`( echo $CURVER | awk -v FS="." '{print $2}')`
CURVER3=`( echo $CURVER | awk -v FS="." '{print $3}')`
CURVER4=`( echo $CURVER | awk -v FS="." '{print $4}')`

REQVER=$2
REQVER1=`( echo $REQVER | awk -v FS="." '{print $1}')`
REQVER2=`( echo $REQVER | awk -v FS="." '{print $2}')`
REQVER3=`( echo $REQVER | awk -v FS="." '{print $3}')`
REQVER4=`( echo $REQVER | awk -v FS="." '{print $4}')`

while [ $COUNT -le 4 ]
do
   FOO="CURVER$COUNT"
   FOO2="REQVER$COUNT"
   if [ $FOO -lt $FOO2 ]
   then
      return 2
   else
      if [ $FOO -gt $FOO2 ]
      then
         return 1
      fi
   fi
COUNT=`expr $COUNT + 1`
done

return 0

}
# check OS System Library required
PatchCheck()
{
FILESET=$1

REQVERS=$2
CURCOUNT=$3

XMLFILE1=$4
XMLFILE2=$5

TEMP=`(lslpp -Lq | grep $FILESET)`
if [ $? -ne 0 ]
then
   TEMP=`(echo "$FILESET NONE" | awk '{printf("OS System Library %-20s  %-12s  FAIL\n",$1,$2)}')`
   #echo "$TEMP  $REQVERS"
   STATUS=-1
else
   CURVERS=`(lslpp -Lq | grep $FILESET | awk '{print $2}')`

   TokenCompare $CURVERS $REQVERS
   if [ $? -eq 0 -o $? -eq 1 ]
   then
      TEMP=`(echo $FILESET $CURVERS | awk '{printf("OS System Library %-20s  %-12s  PASS\n",$1,$2)}')`
      #echo "$TEMP"
      STATUS=1
   else
      TEMP=`(echo $FILESET $CURVERS | awk '{printf("OS System Library %-20s  %-12s  FAIL\n",$1,$2)}')`
      #echo "$TEMP  $REQVERS"
      STATUS=-1
   fi
fi
# add to installStatus.xml
sed s${ca}'<Patch number="'$CURCOUNT'" name="x" msg="x" status="x"/>'\
${ca}'<Patch name="'$FILESET'" msg="'"$TEMP"'" status="'$STATUS'"/>'\
${ca} $XMLFILE1 > $XMLFILE2
}

############################################################################
#  Check WebSphere Commerce version: 5.4 or 5.1?
#
############################################################################

# check 5.1 first

HardCheck CommerceSuite.Base.rte

if [ $? -eq 0 ];
then
   EDITIONTAG="v51pro";
   WCINSTALLED=1;
   WCS51=1;
   # WCS5.1 default pathes
   WCSDIR=/usr/lpp/CommerceSuite

   WASDIR=/usr/IBMWebAS
   DB271HOME=/usr/lpp/db2_07_01
   HTTPHOME=/usr/HTTPServer
   WCEDITION="Professional"
   PAYMENTHOME=/usr/lpp/PaymentManager
else
# check 5.4
HardCheck Commerce.Base.rte 
if [ $? -eq 3 ];
then
   echo "ICChecker require WCS 5.1 or higher installed in your system...."
   echo "Exiting...."
   echo ""
   exit 1;
else
# set the default path for v5.4
   WASDIR=/usr/WebSphere/AppServer
   DB271HOME=/usr/lpp/db2_07_01
   WCSDIR=/usr/WebSphere/CommerceServer
   HTTPHOME=/usr/HTTPServer
   PAYMENTHOME=/usr/lpp/PaymentManager
fi

  WCINSTALLED=1;
  WC54=1;
  
# check the existence of WebSphere Commerce Suite directory.
if [[ ! -d ${WCSDIR} ]];
then
   /usr/bin/echo ""
   /usr/bin/echo "ERROR: Websphere Commerce NOT DETECTED. Expecting $WCSDIR"
   /usr/bin/echo ""
   exit 1
fi  

WCSVERSION=$CURVERS

WCEDITION=`( /usr/bin/cat ${WCSDIR}/bin/build.txt | /usr/bin/awk -v FS=";" '{print $3}' | /usr/bin/awk '{print $2}')`

if [[ "${WCEDITION}" = "" ]];
then
   echo "---------------------------------------------------------"
   echo " EDITION: ERROR in build.txt file"
   echo "---------------------------------------------------------"
   exit 1;
elif [[ "${WCEDITION}" = "Professional" ]];
then
   EDITIONTAG="v54pro";
elif [[ "${WCEDITION}" = "Business" ]];
then
   EDITIONTAG="v54be";
# d38472 - add checking for PCD      
elif [[ "${WCEDITION}" = "PCD" ]];
then
   EDITIONTAG="v54PCD";   
fi
echo ""
fi

WCSVERSION=$CURVERS

#test

############################################################################
# create iccheker/bin and icchecker/log under WCS_InstallPath
#
############################################################################
[[ -d ${WCSDIR}/icchecker ]] || mkdir ${WCSDIR}/icchecker
[[ -d $WCSDIR/icchecker/bin ]] || mkdir $WCSDIR/icchecker/bin 
[[ -d $WCSDIR/icchecker/log ]] || mkdir $WCSDIR/icchecker/log
[[ -d $WCSDIR/icchecker/xml ]] || mkdir $WCSDIR/icchecker/xml
[[ -d $WCSDIR/icchecker/images ]] || mkdir $WCSDIR/icchecker/images
[[ -d $WCSDIR/icchecker/lib ]] || mkdir $WCSDIR/icchecker/lib
# d34130 - add subdir properties
[[ -d $WCSDIR/icchecker/properties ]] || mkdir $WCSDIR/icchecker/properties
[[ -d $WCSDIR/icchecker/help ]] || mkdir $WCSDIR/icchecker/help
ICCBIN=$WCSDIR/icchecker/bin
ICCLOG=$WCSDIR/icchecker/log
ICCXML=$WCSDIR/icchecker/xml
ICCHELP=$WCSDIR/icchecker/help
ICCIMAGES=$WCSDIR/icchecker/images
ICCLIB=$WCSDIR/icchecker/lib

############################################################################
# copy from the source dir to iccheker/bin and
#
# change the mode of shell scipt files in icchecker/bin	
############################################################################
if [[ -d ./bin ]];
	then
		/usr/bin/cp ./bin/*.* ${ICCBIN}
	else
		/usr/bin/echo "ERROR: bin directory not found. Please reinstall."	
		exit 1
fi	
if [[ -d ./xml ]];
	then
		/usr/bin/cp ./xml/*.* ${ICCXML}
	else
		/usr/bin/echo "ERROR: xml directory not found. Please reinstall."	
		exit 1
fi
if [[ -d ./help ]];
	then
		/usr/bin/cp ./help/*.* ${ICCHELP}
	else
		/usr/bin/echo "ERROR: help directory not found. Please reinstall."	
		exit 1
fi
if [[ -d ./images ]];
	then
		/usr/bin/cp ./images/*.* ${ICCIMAGES}
	else
		/usr/bin/echo "ERROR: xml directory not found. Please reinstall."	
		exit 1
fi
if [[ -d ./lib ]];
	then
		/usr/bin/cp ./lib/*.* ${ICCLIB}
	else
		/usr/bin/echo "ERROR: lib directory not found. Please reinstall."	
		exit 1
fi


if [[ -f ${ICCBIN}/runAlias.sh ]];
      then
         /usr/bin/chmod a+x ${ICCBIN}/runAlias.sh         
      else
         /usr/bin/echo "ERROR: runAlias.sh not found. Expecting ${ICCBIN}/runAlias.sh"
         exit 1
fi

if [[ -f ${ICCBIN}/runPs.sh ]];
      then
         /usr/bin/chmod a+x ${ICCBIN}/runPs.sh         
      else
         /usr/bin/echo "ERROR: runPs.sh not found. Expecting ${ICCBIN}/runPs.sh"
         exit 1
fi


############################################################################
# make a backup of installStatus.xml and also a copy of it
#
 if [[ -f ${ICCXML}/InstallStatusTemplate.xml ]];
      then
         #/usr/bin/echo "Backing up InstallStatusTemplate.xml"
         /usr/bin/cp ${ICCXML}/InstallStatusTemplate.xml ${ICCXML}/InstallStatus.xml
         /usr/bin/cp ${ICCXML}/InstallStatusTemplate.xml ${ICCXML}/InstallStatus.xml.tmp
      else
         /usr/bin/echo "ERROR: InstallStatusTemplate.xml not found. Expecting ${ICCXML}/InstallStatusTemplate.xml"
         exit 1
fi
ISXML=${ICCXML}/InstallStatus.xml
ISXMLTMP=${ICCXML}/InstallStatus.xml.tmp

echo "Gathering system information, please wait...."
############################################################################
#  Add current date and time info
#
CURDATE=`/usr/bin/date '+DATE:%m-%d-%y'`
CURTIME=`/usr/bin/date '+TIME:%H:%M:%S'`



sed s${ca}'<Date>x</Date>'${ca}'<Date>'$CURDATE'</Date>'${ca} "$ISXML" > "$ISXMLTMP"
sed s${ca}'<Time>x</Time>'${ca}'<Time>'$CURTIME'</Time>'${ca} "$ISXMLTMP" > "$ISXML"

# change to <Version5.1> </Version5.1>
sed s${ca}'<VersionHW>'${ca}"<$EDITIONTAG>"${ca} "$ISXML" > "$ISXMLTMP"
sed s${ca}'</VersionHW>'${ca}"</$EDITIONTAG>"${ca} "$ISXMLTMP" > "$ISXML"
sed s${ca}'<VersionSW>'${ca}"<$EDITIONTAG>"${ca} "$ISXML" > "$ISXMLTMP"
sed s${ca}'</VersionSW>'${ca}"</$EDITIONTAG>"${ca} "$ISXMLTMP" > "$ISXML"


############################################################################
#  checking hardware and add to InstallStatus.xml
#
# check the machine type and architecture
MACHINETYPE=`uname -M`

CPUTYPE=`(lsattr -E -l proc0 | grep "type" | awk '{print $2}')`

sed s:'<Machine type="x" architecture="x"/>':'<Machine type=\"'$MACHINETYPE'\" architecture=\"'$CPUTYPE'\"/>': "$ISXML" > "$ISXMLTMP"

# check the number of CPUs and get the Processor spd for each of them
# have to add more for Mutiple processor case
NCPU=`(lscfg | grep -c proc)`

sed s${ca}'<Cpu number="x">'${ca}'<Cpu number="'$NCPU'">'${ca} "$ISXMLTMP" > "$ISXML"

# can't check cpu speed in a easy way - need to check the exceptions.
COUNT=0

CPUINFO=`(lsattr -E -l proc0 | grep "frequency")`
if [[ $? = 0 ]]
then
CPUSPEED=`(lsattr -E -l proc0 | grep "frequency" | awk '{print $2}')`
CPUSPEED=`expr $CPUSPEED / 1000000`
else
CPUSPEED=0
fi
sed s:'<Processor slot="0" speed="x" unit="x"/>':'<Processor slot="0" speed="'$CPUSPEED'" unit="MHz"/>': "$ISXML" > "$ISXMLTMP"



# Memory

MEMTOTAL=`(lsattr -E -l sys0 -a realmem | awk '{print $2}')`

MEMPERCPU=`expr $MEMTOTAL / $NCPU`
sed s${ca}'<RAM size="x" unit="x"/>'${ca}'<RAM size="'$MEMPERCPU'" unit="KB"/>'${ca} "$ISXMLTMP" > "$ISXML"


# Paging Space
PAGETOTAL=0
NUMPAGES=`(lsps -a | grep -c -v "THISISJUSTTOCOUNTLINES")`
NUMPAGES=`expr $NUMPAGES - 1`

if [ NUMPAGES -ge 1 ];
then
   for PAGESPACE in `(lsps -a | grep "MB" | /usr/bin/awk '{print $4}' | /usr/bin/awk -v FS="M" '{print $1}')`;
   do
      PAGETOTAL=`expr $PAGETOTAL + $PAGESPACE`
   done

   PAGETOTAL=`expr $PAGETOTAL \* 1024`   
else
      PAGETOTAL=0      
fi

   
sed s${ca}'<PAGINGSPACE size="x" unit="x"/>'${ca}'<PAGINGSPACE size="'$PAGETOTAL'" unit="KB"/>'${ca} "$ISXML" > "$ISXMLTMP"



# System PATH and Java Classpath
sed s${ca}'<EnvPATH value="x"/>'${ca}'<EnvPATH value="'$PATH'"/>'${ca} "$ISXMLTMP" > "$ISXML"

# Java Level check
JAVALEVEL=`( /usr/bin/java -version 2>&1 | grep java | awk '{print $3}') | awk -v FS="\"" '{print $2}'`

sed s${ca}'<Java Level="x" CLASSPATH="x"/>'${ca}'<Java Level="'$JAVALEVEL'" CLASSPATH="'$CLASSPATH'"/>'${ca} "$ISXML" > "$ISXMLTMP"

###########################################################################
# Check installed software level
#
# OS Level for AIX
OSNAME=`uname`

OSLEVEL=`oslevel`

# fix for d35959
if [[ ${OSLEVEL} = "" ]];
then
	OSLEVEL="0.0.0.0"
fi

Tokenize $OSLEVEL $OSNAME "x" "x" "$ISXMLTMP" "$ISXML"

# only check Aix Maintenance Level and Stack Quota limit for WC54 and AIX 5.1 
if [[ $WC54 = 1 && $OSLEVEL = "5.1.0.0" ]]
then
# 
# check AIX Maintenance Level  
# d38472
# ML2 for PCD
  if [ "$WCEDITION" = "PCD" ]
  then
    TEMP=`(instfix -ik 5100-02_AIX_ML 2> /dev/null)`
    if [ $? -ne 0 ];
    then 
      MSG="AIX Maintenance Level 02 or above   FAIL"
      STATUS=-1
    else
      MSG="AIX Maintenance Level 02 or above   PASS"   
      STATUS=1
    fi
  else
    TEMP=`(instfix -ik 5.1.0.0_AIX_ML 2> /dev/null)`
    if [ $? -ne 0 ];
    then 
      MSG="AIX Maintenance Level 01 or above   FAIL"
      STATUS=-1
    else
      MSG="AIX Maintenance Level 01 or above   PASS"   
      STATUS=1
  fi
fi
  
sed s${ca}'<ML name="Maintenance Level" msg="x" status="x"/>'\
${ca}'<ML name="Maintenance Level" msg="'"${MSG}"'" status="'${STATUS}'"/>'\
${ca} $ISXML > $ISXMLTMP


# check Stack Quota Limit
STACKQUOTA=`(ulimit -a | grep "stack" | awk '{print $2}')`

if [ "$STACKQUOTA" = "unlimited" ]
then
   MSG=`(echo $STACKQUOTA $STACK1K | awk '{printf("Stack Quota Limit Current: %-10s Req: %-10s PASS\n",$1,$2)}')`
   STATUS=1
else
   if [ $STACKQUOTA -ge $STACK1K ]
   then
      MSG=`(echo $STACKQUOTA $STACK1K | awk '{printf("Stack Quota Limit Current: %-10s Req: %-10s PASS\n",$1,$2)}')`
      STATUS=1
   else
      MSG=`(echo $STACKQUOTA $STACK1K | awk '{printf("Stack Quota Limit Current: %-10s Req: %-10s FAIL\n",$1,$2)}')`
      STATUS=-1 
   fi
fi

sed s${ca}'<StackQuota name="Stack Quota Limit" msg="x" status="x"/>'\
${ca}'<StackQuota name="Stack Quota Limit" msg="'"$MSG"'" status="'$STATUS'"/>'\
${ca} $ISXMLTMP > $ISXML
fi

# OS System Library - filesets
# TO DO: change the messages
if [[ $WC54 = 1 && $OSLEVEL = "5.1.0.0" ]]
then
PatchCheck X11.adt.lib 5.1.0.0 1 $ISXML $ISXMLTMP
PatchCheck X11.adt.motif 5.1.0.0 2 $ISXMLTMP $ISXML
PatchCheck X11.base.lib 5.1.0.0 3 $ISXML $ISXMLTMP
PatchCheck X11.base.rte 5.1.0.0 4 $ISXMLTMP $ISXML
PatchCheck X11.motif.lib 5.1.0.0 5 $ISXML $ISXMLTMP
PatchCheck bos.adt.base 5.1.0.0 6 $ISXMLTMP $ISXML
PatchCheck bos.adt.include 5.1.0.0 7 $ISXML $ISXMLTMP
PatchCheck bos.rte.net 5.1.0.0 8 $ISXMLTMP $ISXML
PatchCheck bos.rte.libc 5.1.0.0 9 $ISXML $ISXMLTMP
PatchCheck bos.net.tcp.client 5.1.0.0 10 $ISXMLTMP $ISXML
elif [[ $WCS51 = 1 && $OSLEVEL = "4.3.3.0" ]]
then
PatchCheck X11.adt.lib 4.3.3.0 1 $ISXML $ISXMLTMP
PatchCheck X11.adt.motif 4.3.3.1 2 $ISXMLTMP $ISXML
PatchCheck bos.adt.include 4.3.3.1 3 $ISXML $ISXMLTMP
PatchCheck bos.adt.prof 4.3.3.3 4 $ISXMLTMP $ISXML
# clean up leftover

fi


# Websphere Commerce Suite
#
#  Add WCS version and installPath to the XML file
#
# fix for d35959
if [[ ${WCSVERSION} = "" ]];
then
	WCSVERSION="0.0.0.0"
	WCSDIR="x"
	WCEDITION="x"
fi

Tokenize $WCSVERSION "WCS" $WCEDITION $WCSDIR "$ISXML" "$ISXMLTMP"
# reset global variable CURVERS
CURVERS=""


# Websphere Application Server
#
# Add WAS version and installPath to the XML file
#

HardCheck IBMWebAS.base.server
#echo "CURVERS=$CURVERS"
#d38047 - fixed June 25 2002
if [[ $CURVERS = "3.5.0.0" ]]
then
	WAS35=1;
	WASVERSION=3.5
	# check WAS3.5 home dir
        if [ ! -d ${WASDIR} ];
	then
	    echo "WebSphere Application Server Default directory $WASDIR NOT DETECTED"
	while :
	do
  	read CHECK_DIR?"Please enter the WAS HOME directory:"

	   if [[ "${CHECK_DIR}" = "quit" ]];
	   then
		    read JUNK?"Press enter to continue."
		    exit 0
	   fi

	   if [[ -d ${CHECK_DIR} ]];
	   then
    	      WASDIR=$CHECK_DIR
	      #/usr/bin/echo "WAS HOME is $WASDIR"
	   else
    	  /usr/bin/echo "Invalid entry of $CHECK_DIR"
	      continue
	   fi

	   break;
	done
	fi
       # check 3.5 fixpak	
      for DIGIT in 0 1 2 3 4 5 6 7 8 9
      do
          TEMP=`(/usr/bin/grep "<version>3.5.$DIGIT</version>" ${WASDIR}/properties/com/ibm/websphere/product.xml)`
         if [[ $? = 0 ]]                  
	 then
	    WASVERSION=3.5.0.$DIGIT
	    break;
         fi
      done
      # was edition check
      TEMP=`(/usr/bin/grep "<value>advanced</value>" ${WASDIR}/properties/com/ibm/websphere/product.xml)`
      if [[ $? = 0 ]];                  
      then
      	WASEDITION="Advanced"
      else
      	WASEDITION="x"	
      fi	     
	
else
# check WAS 4.0 version
HardCheck IBMWebAS.base.WASserver

if [ $? -eq 3 ];
then
   echo "WAS not installed...."
   echo "Exiting...."
   echo ""
   exit 0;
elif [[ $CURVERS = "4.0.0.0" ]]
then
	WAS40=1
	WASVERSION=4.0
	# check WAS4.0 home dir
	if [ ! -d ${WASDIR} ];
	then
	    echo "WebSphere Application Server 4.0 Default directory $WASDIR NOT DETECTED"
	while :
	do
  	read CHECK_DIR?"Please enter the WAS HOME directory:"

	   if [[ "${CHECK_DIR}" = "quit" ]];
	   then
		    read JUNK?"Press enter to continue."
		    exit 0
	   fi

	   if [[ -d ${CHECK_DIR} ]];
	   then
    	      WASDIR=$CHECK_DIR
	      #/usr/bin/echo "WAS HOME is $WASDIR"
	   else
    	  /usr/bin/echo "Invalid entry of $CHECK_DIR"
	      continue
	   fi

	   break;
	done
	fi
	
	# check 4.0 fixpak	
      for DIGIT in 0 1 2 3 4 5 6 7 8 9
      do
         TEMP=`(/usr/bin/grep "<version>4.0.$DIGIT</version>" ${WASDIR}/properties/com/ibm/websphere/product.xml)`
         if [[ $? = 0 ]];                  
	 then
	    WASVERSION=4.0.0.$DIGIT
	    break;
         fi
      done
      # was edition check
      TEMP=`(/usr/bin/grep "<value>AE</value>" ${WASDIR}/properties/com/ibm/websphere/product.xml)`
      if [[ $? = 0 ]];                  
      then
      	WASEDITION="Advanced"
      else
      	WASEDITION="x"	
      fi
    fi
fi      

# fix for d35959
# exception handling
if [[ "${WASVERSION}" = "" ]]; 
then
	WASVERSION="0.0.0.0"
	#WASDIR="x"	
	WASEDITION="x"
fi	   

Tokenize $WASVERSION WAS $WASEDITION  $WASDIR "$ISXMLTMP" "$ISXML"
#need to reset CURVERS
CURVERS="" 

#
# WAS_JDK level
#
if [ -f ${WASDIR}/java/jre/bin/java ];
then
   WASJAVALEVEL=`( ${WASDIR}/java/jre/bin/java -version 2>&1 | grep java | awk '{print $3}') | awk -v FS="\"" '{print $2}'`
   WAS_JDKPATH=${WASDIR}/java/jre/bin/java       
fi

# exception handling
# fix for d35959
#if [[ "${WASJAVALEVEL}" = "" ]]; 
#then
# skip the check for WASJDK for now
	WASJAVALEVEL="x.0.0.0"
	WAS_JDKPATH="x"
#fi
Tokenize $WASJAVALEVEL "WASJDK" "x" $WAS_JDKPATH "$ISXML" "$ISXMLTMP"

# Database - DB2
#
#echo "========================================================="
#echo "DATABASE: DB2  Check                           "
#echo "========================================================="
DBFOUND=0
O816=0
ORACLEFOUND=0
ORATAB=""

HardCheck db2_07_01.db2.rte 
RETVAL=$?

if [ $RETVAL -eq 0 ];
then
   #echo "IBM DB2 7.1 DATABASE"
   #echo "Ports Used:"
   #grep "DB2 instance" /etc/services | /usr/bin/awk '{printf("%-20s  %-20s\n",$1,$2)}'
     
   DB2VERSION=$CURVERS	
   if [ ! -d ${DB271HOME} ];
   then
      echo "DB2 7.1 Default directory ${DB271HOME} NOT DETECTED"
	while :
	do
  	read CHECK_DIR?"Please enter the DB2 HOME directory:"

	   if [[ "${CHECK_DIR}" = "quit" ]];
	   then
		    read JUNK?"Press enter to continue."
		    exit 0
	   fi

	   if [[ -d ${CHECK_DIR} ]];
	   then
    	      DB271HOME=$CHECK_DIR
	     # /usr/bin/echo "DB2 Home is $DB271HOME"
	   else
    	  /usr/bin/echo "Invalid entry of $CHECK_DIR"
	      continue
	   fi

	   break;
	done      
   fi

  
   DBFOUND=1
   DB2EDITION="Server" 
   
elif [ $RETVAL -eq 3 ];
then
   HardCheck grep db2_07_01.client
   RETVAL=$?
   if [ $RETVAL -eq 0 ];
   then
      #echo "IBM DB2 7.1 DATABASE Client"
      
      #echo "Ports Used:"
      #grep "DB2 instance" /etc/services | /usr/bin/awk '{printf("%-20s  %-20s\n",$1,$2)}'
 
    if [ ! -d ${DB271HOME} ];
	  then
	      echo "DB2 7.1 Default directory ${DB271HOME} NOT DETECTED"
	  while :
	   do
  	   read CHECK_DIR?"Please enter the DB2 HOME directory:"

	   if [[ "${CHECK_DIR}" = "quit" ]];
	   then
		    read JUNK?"Press enter to continue."
		    exit 0
	   fi

	   if [[ -d ${CHECK_DIR} ]];
	   then
    	      DB271HOME=$CHECK_DIR
	    #  /usr/bin/echo "DB2 Home is ${DB271HOME}"
	   else
    	  /usr/bin/echo "Invalid entry of $CHECK_DIR"
	      continue
	   fi

	   break;
	   done
    fi 
    
   DB2EDITION="Client" 
   #echo ""
   #echo "** NOTE: Client Installation of DB2 detected. Remote DB assumed"
   #echo ""
   DBFOUND=1     
   fi 
fi
if [[ "${DB2VERSION}" = "" ]]; 
then
	DB2VERSION="0.0.0.0"
	DB2EDITION="x"
	DB271HOME="x"
fi
Tokenize $DB2VERSION "DB2" $DB2EDITION $DB271HOME $ISXMLTMP $ISXML
#need to reset CURVERS
CURVERS="" 

# Database - Oracle
# TO DO ------ if no Db detected, warn and exit

# Web Server - IBM HTTPD
# 

#echo "========================================================="
#echo "WebServer: IBM HTTP Server "
#echo "========================================================="
WEBSERVERFOUND=0

HardCheck http_server.base.rte
RETVAL=$?
if [ $RETVAL -eq 0 ];
then
   WEBSERVERFOUND=1
      
   if [ ! -d ${HTTPHOME} ];
   then
      echo "IBM HTTP Server default directory ${HTTPHOME} NOT DETECTED"
	while :
	do
  	read CHECK_DIR?"Please enter the IBM HTTP Server HOME directory:"

	   if [[ "${CHECK_DIR}" = "quit" ]];
	   then
		    read JUNK?"Press enter to continue."
		    exit 0
	   fi

	   if [[ -d ${CHECK_DIR} ]];
	   then
    	      HTTPHOME=$CHECK_DIR	      
	   else
    	  /usr/bin/echo "Invalid entry of $CHECK_DIR"
	      continue
	   fi

	   break;
	done      
   fi 
   # use version.signature as it has most accurate info
   if [ -f ${HTTPHOME}/version.signature ];
   then
      CURVERS=`( /usr/bin/cat ${HTTPHOME}/version.signature | awk '{print $4}')`
   fi   
      HTTPDVERSION=$CURVERS	

else #HTTPD not installed
   HTTPVERSION=0.0.0.0     
fi
# exception handling
# fix for d35959
if [[ "${HTTPDVERSION}" = "" ]]; 
then
	HTTPDVERSION="0.0.0.0"
	HTTPHOME="x"
fi

Tokenize $HTTPDVERSION "IBMHTTP" "x" $HTTPHOME $ISXML $ISXMLTMP
#need to reset CURVERS
CURVERS="" 

# Web Server - Sun iPlanet
#  TO DO --------------------- if no Web server found, warn and exit


# Payment Manager - 
# not an easy grep as the version is actually one line below the 1st grep...
# TO DO
PAYMENTFOUND=0
# a few steps to grep the versions for payment manager
FILESET=IBM.WebSphere.Payment.Manager.Framework
PAYINFO=`(lslpp -Lq | grep $FILESET)`

RETVAL=$?
if [ $RETVAL -eq 0 ];
then
	CURLINE=`(lslpp -Lq | grep -n $FILESET | awk -v FS=":" '{print $1}')`
	CURLINE=`expr $CURLINE + 1`
	CURVERS=`(lslpp -Lq | grep -n "IBM WebSphere Payment Manager" | grep "$CURLINE:" | awk '{print$2}')`
	RETVAL=$?
        PAYMENTFOUND=1
        PAYMENTVERSION=$CURVERS
  
   if [ ! -d ${PAYMENTHOME} ];
   then
      echo "IBM WebSphere Payment Manager default directory ${PAYMENTHOME} NOT DETECTED"
	while :
	do
  	read CHECK_DIR?"Please enter the IBM WebSphere Payment Manager HOME directory:"

	   if [[ "${CHECK_DIR}" = "quit" ]];
	   then
		    read JUNK?"Press enter to continue."
		    exit 0
	   fi

	   if [[ -d ${CHECK_DIR} ]];
	   then
    	      PAYMENTHOME=$CHECK_DIR	      
	   else
    	  /usr/bin/echo "Invalid entry of $CHECK_DIR"
	      continue
	   fi

	   break;
	done      
   fi   
fi
# exception handling
if [[ "${PAYMENTVERSION}" = "" ]]
then
	PAYMENTVERSION="0.0.0.0"
	PAYMENTHOME="x"
fi	
Tokenize $PAYMENTVERSION "PaymentManager" "x"  $PAYMENTHOME $ISXMLTMP $ISXML

# reset global variable CURVERS
CURVERS=""
# remove the temp XML file
rm $ISXMLTMP

###########################################################################
#  need to include config classes in the classpath
#  setup Java runtime environment, need to run 1.2.2 or later!!!
export JAVA_HOME=${WASDIR}/java/jre
# WAS35 use a different JAVA_EXE
if [[ $WAS35 = 1 ]]
then
export JAVA_EXE=${JAVA_HOME}/sh/java
else
export JAVA_EXE=${JAVA_HOME}/bin/java
fi
#echo "JAVA_EXE=${JAVA_EXE}"
CLASSPATH=$CLASSPATH:$WCSDIR/lib/xml4j.jar
CLASSPATH=$CLASSPATH:$WCSDIR/lib/wcsconfig.jar
CLASSPATH=$CLASSPATH:$WASDIR/lib/xerces.jar
CLASSPATH=$CLASSPATH:$ICCLIB/icchecker.jar
#d36920 - add xmlconfig.jar to classpath
# need to add WC54 and WCS51 specific jar files
if [[ $WCS51 = 1 ]]
then
CLASSPATH=$CLASSPATH:$WASDIR/lib/ibmwebas.jar
else
CLASSPATH=$CLASSPATH:$WASDIR/lib/xmlconfig.jar
fi
# d36920 - add additional jar files to the classpath
CLASSPATH=$CLASSPATH:$WASDIR/lib/ujc.jar
CLASSPATH=$CLASSPATH:$WASDIR/lib/console.jar
CLASSPATH=$CLASSPATH:$WASDIR/lib/repository.jar
CLASSPATH=$CLASSPATH:$WASDIR/lib/tasks.jar
export CLASSPATH

###########################################################################
#  need to set the path for java 1.2.2
#PATH=/usr/java_dev2/jre/sh:/usr/java_dev2/sh:$PATH:/usr/bin:/etc
############################################################################
#invoke icchecker through MainInputScreen
echo "Running icchecker for AIX, please wait...."
${JAVA_EXE} com.ibm.commerce.icchecker.MainInputScreen ${WCSDIR} $EDITIONTAG 2>./log/error.log

